@@ -32,7 +32,7 @@ module FFaker
     end
 
     def expedition_date
-      today = Date.today
+      today = ::Date.today
       today - rand(today.year)
     end
   end
