@@ -1,7 +1,6 @@
-# encoding: utf-8
+# frozen_string_literal: true
 
 module FFaker
-  # Author AntonyFalegkos<falegk1@gmail.com> github.com/falegk
   module NameGR
     extend ModuleUtils
     extend self
@@ -9,7 +8,7 @@ module FFaker
     # Random full name (male or female). Arguments :male, :female, :any
     def full_name(gender = :any)
       case gender
-      when :any then rand(0..1) == 0 ? male_full_name : female_full_name
+      when :any then rand(0..1).zero? ? male_full_name : female_full_name
       when :male then male_full_name
       when :female then female_full_name
       else raise ArgumentError, 'Invalid gender, must be one of :any, :male, :female'
