@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestAWS < Test::Unit::TestCase
   include DeterministicHelper
@@ -20,6 +20,6 @@ class TestAWS < Test::Unit::TestCase
   end
 
   def test_product_description
-    assert_match(%r{\A[ \/a-zA-Z\(\)]+\z}i, FFaker::AWS.product_description)
+    assert_match(%r{\A[ /a-zA-Z()]+\z}i, FFaker::AWS.product_description)
   end
 end
