@@ -1,13 +1,13 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestBank < Test::Unit::TestCase
   include DeterministicHelper
 
   assert_methods_are_deterministic(
     FFaker::Bank,
-    :iban, :card_number, :card_expiry_date, :card_type
+    :iban, :card_number, :card_expiry_date, :card_type, :loan_interest_rate, :loan_term, :loan_amount
   )
 
   def setup
@@ -33,7 +33,7 @@ class TestBank < Test::Unit::TestCase
     date_today = ::DateTime.now
 
     assert_random_between(
-      date_today.strftime('%y'), date_today.next_year(5).strftime('%y')
+      date_today.strftime('%y')..date_today.next_year(5).strftime('%y')
     ) do
       @tester.card_expiry_date.split('/').pop
     end
@@ -41,8 +41,7 @@ class TestBank < Test::Unit::TestCase
     year_range = 4
     year_latest = 8
     assert_random_between(
-      date_today.prev_year(year_latest + year_range).strftime('%y'),
-      date_today.prev_year(year_latest).strftime('%y')
+      date_today.prev_year(year_latest + year_range).strftime('%y')..date_today.prev_year(year_latest).strftime('%y')
     ) do
       @tester.card_expiry_date(year_range: year_range, year_latest: year_latest).split('/').pop
     end
@@ -51,4 +50,18 @@ class TestBank < Test::Unit::TestCase
   def test_card_type
     assert_include @tester::CARD_TYPES, @tester.card_type
   end
+
+  def test_loan_interest_rate
+    rate = FFaker::Bank.loan_interest_rate
+    assert(rate.to_f.between?(1.5, 15.0), "Rate #{rate} is out of bounds")
+  end
+
+  def test_loan_term
+    assert_includes([12, 24, 36, 48, 60, 72, 84], FFaker::Bank.loan_term)
+  end
+
+  def test_loan_amount
+    amount = FFaker::Bank.loan_amount
+    assert(amount.between?(1_000, 100_000), "Amount #{amount} is out of bounds")
+  end
 end
