@@ -25,12 +25,15 @@ class TestFakerInternetSE < Test::Unit::TestCase
   end
 
   def test_disposable_email
-    assert @tester.disposable_email.match(/.+@(mailinator\.com|suremail\.info|spamherelots\.com|binkmail\.com|safetymail\.info)/)
+    assert @tester.disposable_email.match(
+      /.+@(mailinator\.com|suremail\.info|spamherelots\.com|binkmail\.com|safetymail\.info)/
+    )
   end
 
   def test_free_email
     email = @tester.free_email
-    assert email.match(/.+@(gmail\.com|hotmail\.com|yahoo\.com|spray\.se|passagen\.se)/), "mail: #{email} does not match"
+    assert email.match(/.+@(gmail\.com|hotmail\.com|yahoo\.com|spray\.se|passagen\.se)/),
+           "mail: #{email} does not match"
   end
 
   def test_login_user_name
