@@ -5,9 +5,9 @@ require_relative 'helper'
 class TestLoremRU < Test::Unit::TestCase
   include DeterministicHelper
 
-  SENTENCE_MATCHER = /\A[а-яА-ЯёЁ\-\s.!?,]+\z/.freeze
-  WORDS_MATCHER    = /\A[А-Яа-яёЁ\-\s]+\z/.freeze
-  WORD_MATCHER     = /\A[А-Яа-яёЁ\-]+\z/.freeze
+  SENTENCE_MATCHER = /\A[а-яА-ЯёЁ\-\s.!?,]+\z/
+  WORDS_MATCHER    = /\A[А-Яа-яёЁ\-\s]+\z/
+  WORD_MATCHER     = /\A[А-Яа-яёЁ-]+\z/
 
   assert_methods_are_deterministic(
     FFaker::LoremRU,
