@@ -5,7 +5,7 @@ require_relative 'helper'
 class TestFakerNamePH < Test::Unit::TestCase
   include DeterministicHelper
 
-  PH_REGEXP = /\A([\wñÑú-]+\.? ?){2,5}\z/.freeze
+  PH_REGEXP = /\A([\wñÑú-]+\.? ?){2,5}\z/
 
   assert_methods_are_deterministic(
     FFaker::NamePH,
