@@ -5,8 +5,8 @@ require_relative 'helper'
 class TestNameRU < Test::Unit::TestCase
   include DeterministicHelper
 
-  RU_REGEX = /\A[а-яА-Я]{2,}\z/.freeze
-  RU_REGEX_MULTIPLE_WORDS = /\A[а-яА-Я\s]+\z/.freeze
+  RU_REGEX = /\A[а-яА-Я]{2,}\z/
+  RU_REGEX_MULTIPLE_WORDS = /\A[а-яА-Я\s]+\z/
 
   assert_methods_are_deterministic(
     FFaker::NameRU,
