@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'helper'
+require_relative 'helper'
 
 class TestSSNSE < Test::Unit::TestCase
   include DeterministicHelper
@@ -12,8 +12,8 @@ class TestSSNSE < Test::Unit::TestCase
     assert_match(/(19|20)\d{10}/, ssn, "With no arguments year should start with 19 or 20, #{ssn}")
   end
 
-  def equal?(nbr)
-    nbr % 2
+  def equal?(other)
+    other % 2
   end
 
   def test_ssn_with_gender
@@ -24,7 +24,7 @@ class TestSSNSE < Test::Unit::TestCase
     assert equal?(ssn_female[10].to_i)
 
     assert_raise ArgumentError do
-      FFaker::SSNSE.ssn(gender: :unkown)
+      FFaker::SSNSE.ssn(gender: :unknown)
     end
   end
 
@@ -32,7 +32,7 @@ class TestSSNSE < Test::Unit::TestCase
     from = Time.local(1980, 2, 28)
     to = Time.local(2000, 2, 28)
 
-    assert_random_between(from, to, exclude_end: true) do
+    assert_random_between(from...to) do
       ssn = FFaker::SSNSE.ssn(from: from, to: to)
       year = ssn[0..3].to_i
       month = ssn[4..5].to_i
